@@ -32,25 +32,21 @@ programa, armazenada no arquivo COPYING).
 */
 
 #include "document.h"
+#include "vlayer.h"
+#include "export.h"
 #include <stdbool.h>
 
-#include <bores.h>
+#include "bores/bores.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
 
-#define SUPPRESS_NEVER 0           /* never suppress newlines */
-#define SUPPRESS_ONSAMEWIDTH 1     /* only when term width == output width */
-#define SUPPRESS_ALWAYS 2          /* always suppress newlines */
-
 bool clear_screen = false;
-int suppress_newlines = SUPPRESS_NEVER; 
-                           /* when to suppress newlines on output. See
-                            * SUPPRESS_ constants */
+bool suppress_newlines = false;
+                           /* whether to suppress newlines on output. */
 bool use_color = true;
 char *outputfile;
-int termwidth;    /* attributed in main() from the COLUMNS env variable */
 
 FILE *f;
 
@@ -59,19 +55,6 @@ int layer_number; /* the layer we will output; -1 means composite */
 Layer *lyr;       /* the layer we are printing; NULL if printing composite */
 int width, height;
 
-struct decoded_cell_t {  /* represents a decoded document cell. Returned
-                          * by decode_cell */
-
-   int fg, bg;      /* the foreground and background color codes (4 bit, 0-15)
-                     * for the cell */
-   int ch;          /* the character in the cell */
-
-   /* now some of the same information, but in a more broken-down form: */
-   bool bold, blink;  /* bold and blink attributes */
-   int fg3, bg3;       /* 3-bit color codes (0-7) for the foreground and
-                        * background of the cell */
-};
-
 struct html_output_state_t {
    bool font_tag_open, blink_tag_open;  /* which html tags are open */
    int color;       /* The color we are currently outputting text in.
@@ -82,61 +65,32 @@ struct html_output_state_t {
 
 /* Extracts a cell from the appropriate layer (or build one, 
  * if we are dealing with a composite). Returns it. */
-Cell get_cell(int x, int y) {
-   if (lyr) return lyr->cells[x][y];
-   else     return document_calc_effective_cell(doc, x, y);
+void get_decoded_cell(int x, int y, DecodedCell *dec) {
+   if (lyr) decode_cell(&lyr->cells[x][y], dec);
+   else {
+      Cell c = document_calc_effective_cell(doc, x, y);
+      decode_cell(&c, dec);
+   }
 }
 
-/* Decodes a cell into components */
-struct decoded_cell_t decode_cell(Cell cell) {
-   struct decoded_cell_t dec;
-   dec.fg     = (cell.attr & 0xf0) >> 4;
-   dec.bg     = cell.attr & 0x0f;
-   dec.ch     = cell.ch;
-
-   dec.fg3   = (cell.attr & 0x70) >> 4;
-   dec.bg3   = cell.attr & 0x07;
-   dec.bold  = (cell.attr & 0x80) ? 1 : 0;
-   dec.blink = (cell.attr & 0x08) ? 1 : 0;
-
-   return dec;
-};
-
 void output_text(void) {
-   int x, y;
-   struct decoded_cell_t dec;
-   int cur_fg = -1;
-   int cur_bg = -1; 
+   VirtualLayer *vl;
 
-   if (clear_screen)
-      fputs("\e[2J\e[H", f);
+   if (lyr) vl = vlayer_create_from_layer(lyr);
+   else     vl = vlayer_create_from_composite(doc);
 
-   for (y = 0; y < height; y++) {
-      for (x = 0; x < width; x++) {
-         dec  = decode_cell(get_cell(x, y));
-
-         /* set up color if necessary */
-         if (use_color && (dec.fg != cur_fg || dec.bg != cur_bg)) {
-            fputs("\e[", f);
-            fputs(dec.bold ? "1;" : "0;", f);
-            if (dec.blink) fputs("5;", f);
-            fprintf(f, "%d;%dm", 30 + dec.fg3, 40 + dec.bg3);
-
-            cur_fg = dec.fg;
-            cur_bg = dec.bg;
-         }
-
-         /* output the character */
-         if (dec.ch >= 0 && dec.ch <= 32) dec.ch = ' ';
-         fputc(dec.ch, f);
-      }
-      
-      if (suppress_newlines == SUPPRESS_NEVER || 
-         (suppress_newlines == SUPPRESS_ONSAMEWIDTH && termwidth != width))
-            fputc('\n', f);
+   if (!vl) {
+      fprintf(stderr, "Error creating virtual layer. Is the document empty?\n");
+      exit(2);
    }
 
-   fputs("\e[0m", f);
+   if (clear_screen) fputs("\x1B[2J\x1B[H", f);
+   if (!export_vlayer_to_ansi(vl, use_color, !suppress_newlines, false, f)) {
+      fprintf(stderr, "Error exporting virtual layer to ansi.\n");
+      exit(2);
+   }
+
+   vlayer_destroy(vl);
 }
 
 #define COL_BLACK 0
@@ -157,13 +111,14 @@ static char *hex_codes[16] = {
 void output_html(void) {
    int x, y;
    struct html_output_state_t cur_state;
-   struct decoded_cell_t dec;
+   DecodedCell dec;
 
-   fputs("<html><body style=\"color:#ffffff;background-color:#000000;\"><pre>", f);
+   fputs("<html><body style=\"color:#ffffff;background-color:#000000;\">"
+                                                                "<pre>", f);
 
    for (y = 0; y < height; y++) {
       for (x = 0; x < width; x++) {
-         dec = decode_cell(get_cell(x, y));
+         get_decoded_cell(x, y, &dec);
 
 	 /* first set up the blink tag */
 	 if (use_color && dec.blink != cur_state.blink_tag_open) {
@@ -198,11 +153,20 @@ void output_html(void) {
    fputs("</pre></body></html>", f);
 }
 
+void output_comment(void) {
+   printf ("%s\n", doc->metainfo);
+}
+
+void output_layercount(void) {
+   printf ("%d\n", doc->layer_count);
+}
+
 #define MYSYNTAX \
    "Syntax: aecat [-b] [-c] [-{n|N}] [{-p | -l <layer_num>}]\n" \
    "               [-f <format>] [-o <output_file>] inputfile\n" \
    "\n" \
-   "   -f : specifies output format - either text or html\n" \
+   "   -f : specifies output format - can be text, html or comment\n" \
+   "        The 'comment' format extracts document metadata.\n" \
    "   -c : prepend a 'clear screen' escape sequence (only valid when\n" \
    "        outputting text)\n" \
    "   -o : writes output to specified file rather than stdout\n" \
@@ -211,14 +175,11 @@ void output_html(void) {
    "   -l : specifies which layer of the document is to be used.\n" \
    "        (must be an index, not a layer name). By default,\n" \
    "        layer 0 will be used.\n" \
+   "   -L : displays how many layers the document has.\n" \
    "   -p : exports a composite, that is, overlays all visible layers,\n" \
    "        paying attention to layer transparency, etc. The size of the\n" \
    "        composite will be the size of the first layer\n" \
-   "   -n : suppress output of newlines when the width of the terminal\n" \
-   "        is equal to the width of the output (this makes it look\n" \
-   "        right because the cursor will advance to the next line\n" \
-   "        automatically, making the newline superfluous.\n" \
-   "   -N : suppress output of newlines no matter what\n" \
+   "   -n : suppress output of newlines\n" \
    "   -h : prints this help text\n"
 
 void rtfm() {  /* rtfm = Read the FAQ and Manual, of course :-) */
@@ -228,35 +189,32 @@ void rtfm() {  /* rtfm = Read the FAQ and Manual, of course :-) */
 
 #define FMT_TEXT 1
 #define FMT_HTML 2
+#define FMT_COMMENT 3
+#define FMT_LAYERS 4
 
 int main(int argc, char **argv) {
-   static char optstring[] = "o:chl:bpf:nN";
+   static char optstring[] = "o:chl:Lbpf:n";
    char *inputfile;
-   char *s;
    int ch;
    
    int out_fmt = 0; /* In what format to output. */
 
-   /* Try to detect terminal width from the COLUMNS environment variable.
-    * We could instead use tcgetattr and the like, but we want to use
-    * COLUMNS to allow the user to fool the program into using a different
-    * value if need be */
-   if ( (s = getenv("COLUMNS")) ) termwidth = atoi(s);
-   
    while (0 < (ch = getopt(argc, argv, optstring)) ) {
       switch (ch) {
          case 'c': clear_screen = true; break;
          case 'o': outputfile = strdup(optarg); break;
          case 'l': layer_number = atoi(optarg); break;
+         case 'L': out_fmt = FMT_LAYERS; break;
          case 'p': layer_number = -1; break;
          case 'b': use_color = false; break;
-	 case 'n': suppress_newlines = SUPPRESS_ONSAMEWIDTH; break;
-	 case 'N': suppress_newlines = SUPPRESS_ALWAYS; break;
+	 case 'n': suppress_newlines = true; break;
          case 'f':
-            if(strcmp(optarg, "text") == 0)
+            if (strcmp(optarg, "text") == 0)
                out_fmt = FMT_TEXT;
-            else if(strcmp(optarg, "html") == 0)
+            else if (strcmp(optarg, "html") == 0)
                out_fmt = FMT_HTML;
+            else if (strcmp(optarg, "comment") == 0)
+               out_fmt = FMT_COMMENT;
             else {
                fprintf(stderr, "Invalid format \"%s\"\n", optarg);
                exit(1);
@@ -273,7 +231,7 @@ int main(int argc, char **argv) {
       fprintf(stderr, "Warning: -c option only valid when outputting text\n");
 
    if (out_fmt != FMT_TEXT && suppress_newlines)
-      fprintf(stderr, "Warning: -n/-N options only valid when "
+      fprintf(stderr, "Warning: -n option only valid when "
                       "outputting text\n");
    
    if (optind >= argc) rtfm();
@@ -299,18 +257,19 @@ int main(int argc, char **argv) {
    height = doc->layers[0]->height;
    lyr = layer_number >= 0 ? doc->layers[layer_number] : NULL;
    
-   f = stdout;  /* notice that we are reusing f, which now identifies
-                 * the file we are outputting information to */
-
    if (outputfile && !(f = fopen(outputfile, "w"))) {
       fprintf(stderr, "Error opening %s for writing.\n", outputfile);
       exit(1);
    }
+   else f = stdout; /* print to standard output if no output file specified */
 
    switch(out_fmt) {
       case FMT_TEXT: output_text(); break;
       case FMT_HTML: output_html(); break;
+      case FMT_COMMENT: output_comment(); break;
+      case FMT_LAYERS: output_layercount(); break;
    }
 
+   if (f != stdout) fclose(f);
    return 0;
 }
