@@ -32,7 +32,7 @@ programa, armazenada no arquivo COPYING).
 */
 
 
-#include <bores.h>
+#include "bores/bores.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <limits.h>
@@ -48,6 +48,7 @@ programa, armazenada no arquivo COPYING).
 #include "handlekey.h"
 #include "welcomedlg.h"
 #include "keybind.h"
+#include "init_aewl.h"
 
 /* ----------------------------------------------------------------------- */
 /* function declarations                                                   */
@@ -202,6 +203,7 @@ int main(int argc, char **argv) {
    atexit(kurses_finalize);
    keys_init();
    keybind_init();
+   init_aewl();
 
    if (argc >= 2)
       u_load_file(argv[1]);
