@@ -47,33 +47,35 @@ programa, armazenada no arquivo COPYING).
 #define COMMAND_SHOW_HELP_DLG         7 
 #define COMMAND_LOAD_FILE             8
 #define COMMAND_SAVE_FILE             9
-#define COMMAND_EDIT_META            10
-#define COMMAND_MOVE_LEFT            11
-#define COMMAND_MOVE_RIGHT           12
-#define COMMAND_MOVE_UP              13
-#define COMMAND_MOVE_DOWN            14
-#define COMMAND_CARRIAGE_RETURN      15
-#define COMMAND_PAGE_DOWN            16
-#define COMMAND_PAGE_UP              17
-#define COMMAND_START_OF_LINE        18
-#define COMMAND_END_OF_LINE          19
-#define COMMAND_FAST_LEFT            20
-#define COMMAND_FAST_RIGHT           21
-#define COMMAND_PICK_COLOR           22
-#define COMMAND_TINT_CELL            23
-#define COMMAND_TOGGLE_SELECTION     24
-#define COMMAND_CANCEL               25
-#define COMMAND_SHOW_LAYER_DLG       26
-#define COMMAND_NEXT_LAYER           27
-#define COMMAND_PREV_LAYER           28
-#define COMMAND_DUP_LAYER            29
-#define COMMAND_RENAME_LAYER         30
-#define COMMAND_TOGGLE_LINE_MODE     31
-#define COMMAND_TOGGLE_COMPOSITE     32
-#define COMMAND_QUIT                 33
-#define COMMAND_NEW_FILE             34
-#define COMMAND_SHOW_ABOUT_DLG       35
-#define COMMAND_TOTAL                36  /* total number of commands 
+#define COMMAND_SAVE_FILE_AS         10
+#define COMMAND_EDIT_META            11
+#define COMMAND_MOVE_LEFT            12
+#define COMMAND_MOVE_RIGHT           13
+#define COMMAND_MOVE_UP              14
+#define COMMAND_MOVE_DOWN            15
+#define COMMAND_CARRIAGE_RETURN      16
+#define COMMAND_PAGE_DOWN            17
+#define COMMAND_PAGE_UP              18
+#define COMMAND_START_OF_LINE        19
+#define COMMAND_END_OF_LINE          20
+#define COMMAND_FAST_LEFT            21
+#define COMMAND_FAST_RIGHT           22
+#define COMMAND_PICK_COLOR           23
+#define COMMAND_TINT_CELL            24
+#define COMMAND_TOGGLE_SELECTION     25
+#define COMMAND_CANCEL               26
+#define COMMAND_SHOW_LAYER_DLG       27
+#define COMMAND_NEXT_LAYER           28
+#define COMMAND_PREV_LAYER           29
+#define COMMAND_DUP_LAYER            30
+#define COMMAND_RENAME_LAYER         31
+#define COMMAND_TOGGLE_LINE_MODE     32
+#define COMMAND_TOGGLE_COMPOSITE     33
+#define COMMAND_QUIT                 34
+#define COMMAND_NEW_FILE             35
+#define COMMAND_SHOW_ABOUT_DLG       36
+#define COMMAND_RESIZE_LAYER         37
+#define COMMAND_TOTAL                38  /* total number of commands 
                                             (for sizing arrays and the like) */
 
 #endif
