@@ -33,7 +33,7 @@ programa, armazenada no arquivo COPYING).
 
 
 #include <stdbool.h>
-#include <bores.h>
+#include "bores/bores.h"
 #include <limits.h>
 #include <stdlib.h>
 #include <ncurses.h>
@@ -57,6 +57,7 @@ programa, armazenada no arquivo COPYING).
 #include "commands.h"
 #include "menubar.h"
 #include "welcomedlg.h"
+#include "filedlg.h"
 
 #define FAST_MOVE_AMOUNT 8  /* how much the cursor moves each time the fast
                              * movent keys (Ctrl+Z, Ctrl+X) are pressed */
@@ -107,6 +108,33 @@ static void u_rename_layer(void) {
    if (new_name) free(new_name);
 }
 
+/* Interacts with the user in order to allow him to resize the current
+ * layer */
+static void u_resize_layer(void) {
+   Layer *l = _doc->layers[_lyr];
+   Layer *new_l;
+   int h, w, x, y;
+   
+   w = ui_ask_i("RESIZE LAYER: Enter new width", 
+                     l->width,  2, INT_MAX); if (ui_cancel) return;
+   h = ui_ask_i("RESIZE LAYER: Enter new height", 
+                     l->height, 2, INT_MAX); if (ui_cancel) return;
+
+   new_l = layer_create(l->name, w, h);
+
+   w = l->width  > new_l->width  ? new_l->width  : l->width;
+   h = l->height > new_l->height ? new_l->height : l->height;
+
+   for (y = 0; y < h; y++)
+      for (x = 0; x < w; x++) {
+         new_l->cells[x][y].ch   = l->cells[x][y].ch;
+         new_l->cells[x][y].attr = l->cells[x][y].attr;
+      }
+
+   layer_destroy(l);
+   _doc->layers[_lyr] = new_l;
+}
+
 /* Duplicates current layer, adding a duplicate to the end of the
  * layer stack. */
 static void u_dup_layer(void) {
@@ -195,31 +223,14 @@ static char *expand_tilde(char *filename) {
  * this routine will not ask the user for the filename but will
  * rather use the supplied filename as the file to load. */
 void u_load_file(const char *supplied_filename) {
-   char *filename, *expanded_filename;
+   char *filename;
    FILE *f = NULL;
    char msg[128];
    Document *newdoc;
 
    if (!supplied_filename) {
-      filename = ui_ask_s("Load file", NULL);
-      if (ui_cancel || !*filename) {
-         free(filename);
-         return;
-      }
-
-      if (*filename == '~') {
-         if ( !(expanded_filename = expand_tilde(filename)) ) {
-            free(filename);
-            return;
-         }
-
-         /* Comparing pointers here. If no expansion
-          * was made, original filename is returned. */
-         if (expanded_filename != filename) {
-            free(filename);
-            filename = expanded_filename;
-         }
-      }
+      filename = filedlg_show("Load File");
+      if (!filename) return;
    }
    else filename = strdup(supplied_filename);
 
@@ -243,22 +254,24 @@ cleanup:
 }
 
 /* Interacts with the user allowing him to save current file */
-static void u_save_file(void) {
+static void u_save_file(bool forceAsk) {
    char *filename, *expanded_filename;
    FILE *tmpf;
    AeFile *f = 0;
    char msg[128];
 
-   filename = ui_ask_s("Save file as", _filename);
-   if (!filename || !*filename || ui_cancel) return;
+   if (forceAsk || !_filename || !strlen(_filename)) {
+      filename = filedlg_show("Save File As");
+      if (!filename) return;
+   }
+   else filename = strdup(_filename);
 
-   if(filename[0] == '~') {
+   if (filename[0] == '~') {
       expanded_filename = expand_tilde(filename);
-      if(!expanded_filename)
-         return;
+      if (!expanded_filename) return;
 
       /* Comparing pointers. */
-      if(expanded_filename != filename) {
+      if (expanded_filename != filename) {
          free(filename);
          filename = expanded_filename;
       }
@@ -284,6 +297,9 @@ static void u_save_file(void) {
 
    dstrset(&_filename, filename);
 
+   sprintf(msg, "File saved: %s.", filename);
+   ui_message(msg, UIMSG_INFORM);
+
 cleanup:
    if (f) aeff_close(f);
    if (filename) free(filename);
@@ -440,6 +456,14 @@ void handle_key(int ch) {
    int command;
    Layer *lyr;
 
+   /* ENABLE THIS TO DEBUG AEWL... */
+   #if 0
+      if (ch == KEY_F(10)) {
+         debug_aewl();
+         return;
+      }
+   #endif
+
    /* first check for function keys (they open the menu) */
    if (ch > KEY_F0 && ch <= KEY_F(12)) {
       /* show menu and perform command mandated by it */
@@ -498,11 +522,15 @@ void handle_key(int ch) {
 
 void handle_command(int command) {
    int newfg, newbg;
+   int ret;
    Layer *lyr;
 
    /* handle commands that work regardless of whether document is empty */
    switch (command) {
-      case COMMAND_QUIT: exit(0); break;
+      case COMMAND_QUIT: 
+         ret = ui_ask_yn("Really quit aewan?", 0);
+         if (!ui_cancel && ret) exit(0);
+         break;
       case COMMAND_ADD_LAYER_DEFAULTS:
       case COMMAND_ADD_LAYER_SPECIFY:
          u_add_layer(command == COMMAND_ADD_LAYER_SPECIFY);
@@ -522,8 +550,13 @@ void handle_command(int command) {
       case COMMAND_SHOW_HELP_DLG:  show_help_dlg(); return;
       case COMMAND_SHOW_ABOUT_DLG: show_welcome_dlg(); return;
       case COMMAND_LOAD_FILE: u_load_file(NULL); return;
-      case COMMAND_SAVE_FILE: u_save_file(); return;
+      case COMMAND_SAVE_FILE: u_save_file(false); return;
+      case COMMAND_SAVE_FILE_AS: u_save_file(true); return;
       case COMMAND_NEW_FILE:
+         if (_doc->layer_count > 0) {
+            ret = ui_ask_yn("Really start a new document?", 0);
+            if (ui_cancel || !ret) break;
+         }
          document_destroy(_doc);
          zero_state();
          return;
@@ -580,6 +613,7 @@ void handle_command(int command) {
       case COMMAND_PREV_LAYER:   switch_to_layer(_lyr-1); break;
       case COMMAND_DUP_LAYER:    u_dup_layer(); break;
       case COMMAND_RENAME_LAYER: u_rename_layer(); break;
+      case COMMAND_RESIZE_LAYER: u_resize_layer(); break;
 
       case COMMAND_TOGGLE_LINE_MODE:  _lgmode = !_lgmode; break;
       case COMMAND_TOGGLE_COMPOSITE:  _compmode = !_compmode; break;
