@@ -31,7 +31,7 @@ License para obter mais detalhes (uma cpia acompanha este
 programa, armazenada no arquivo COPYING).
 */
 
-#include <bores.h>
+#include "bores/bores.h"
 #include <ncurses.h>
 
 #include "helpdlg.h"
@@ -56,6 +56,7 @@ static char *helptext[2] = {
 "%A     add layer (specify)\n"
 "^D     add copy of current layer\n"
 "^R     rename this layer\n"
+"%R     resize this layer\n"
 "\n"
 "\001Selection\002\n"
 "%S     enter select mode.\n"
