@@ -33,7 +33,7 @@ programa, armazenada no arquivo COPYING).
 
 #include <stdlib.h>
 #include <ncurses.h>
-#include <bores.h>
+#include "bores/bores.h"
 
 #include "keybind.h"
 #include "keys.h"
@@ -81,6 +81,7 @@ void keybind_init(void) {
    cmdforkey[KEY_CTRL_G]       = COMMAND_TOGGLE_LINE_MODE;
    cmdforkey[KEY_CTRL_P]       = COMMAND_TOGGLE_COMPOSITE;
    cmdforkey[KEY_IC]           = COMMAND_TOGGLE_INSERT;
+   cmdforkey[KEY_ALT_R]        = COMMAND_RESIZE_LAYER;
 }
 
 int keybind_translate(int key) {
