@@ -31,7 +31,7 @@ License para obter mais detalhes (uma cpia acompanha este
 programa, armazenada no arquivo COPYING).
 */
 
-#include <bores.h>
+#include "bores/bores.h"
 #include <ncurses.h>
 #include <string.h>
 #include <stdlib.h>
@@ -52,7 +52,7 @@ static void ui_prepare_ex(int fg, int bg) {
 }
 
 static void ui_prepare(void) {
-   ui_prepare_ex(0, 7);
+   ui_prepare_ex(15, 4);
 }
 
 
