@@ -31,7 +31,7 @@ License para obter mais detalhes (uma cpia acompanha este
 programa, armazenada no arquivo COPYING).
 */
 
-#include <bores.h>
+#include "bores/bores.h"
 #include <ncurses.h>
                                                                                 
 #include "welcomedlg.h"
